<?php

class Admin_CustomPostType extends SmugPress {
	var $albums;
	var $templates;
	function __construct() {
            add_action( 'init', array(&$this, 'create_post_type') );
            add_action('admin_menu',array(&$this,'add_options_to_page'));
            add_action('template_redirect', array(&$this,'my_template'), 5);
            register_activation_hook(__FILE__, array(&$this,'smp_rewrite_flush') );
            $this->default_template();
	}
	function smp_rewrite_flush() {
	  $this->create_post_type();
	  flush_rewrite_rules();
	}
	function create_post_type() {
            $labels = array(
                'name' => __( 'SmugMug Galleries' ),
                'singular_name' => __( 'SmugMug Gallery' ),
                'add_new' => __( 'Add Gallery' ),
                'view_item' => __('View Gallery'),
                'search_items' => __('Search Galleries'),
                'add_new_item' => __( 'Add New Gallery' ),
                'edit_item' => __( 'Edit Gallery' ),
                'menu_name' => __( 'Galleries' ),
                );
            $args = array(
                'labels' => $labels,
                'public' => true,
                'has_archive' => true,
                'hierarchical' => true,
                'capability_type' => 'page',
                'supports' => array(
                    'title',
                    'editor',
                    'page-attributes'
                    ),
                'rewrite' => array(
                    'slug' => 'galleries'
                    ),
                );
            register_post_type( 'smp-album',$args );
	}
	public function add_options_to_page() {
		global $custom_post_type_forms;
		//print_r($this->templates);
		add_meta_box( 'smugpress-meta-boxes', __('SmugMug Options'), array(&$custom_post_type_forms,'page_meta_boxes'), 'smp-album', 'side', 'default' );
	}
	function default_template() {
		global $post;
		
		$album_template = get_post_meta($post->ID,'smp_custom_post_template',true);
		
		if ( $album_template == '' )
			add_post_meta( $post->ID, 'smp_custom_post_template', 'default', true );
			
	}
	function my_template() {
		global $post;
		
		$post_type = get_query_var('post_type');
		
		$album_template = get_post_meta($post->ID,'smp_custom_post_template',true);
		
		$default_template = get_template_directory() . '/page.php';
		
		//print_r($default_template);
		
		if ($post_type == 'smp-album') {  // check your post type
				//print_r(TEMPLATE_DIR);
				if($album_template != 'default') {
					load_template(TEMPLATE_DIR . $album_template . '.php');					
				} else {
					load_template($default_template);	
				}

			exit;
	
		}
	
	}
        
        function get_file_extension($file_name) {
		return substr(strrchr($file_name,'.'),1);
	}
        
        function directory_list($directory_base_path,$type) {
		$directory_base_path = rtrim($directory_base_path, "/") . "/";
		
		 // create an array to hold directory list
	    $results = array();
	
	    // create a handler for the directory
	    $handler = opendir($directory_base_path);
		$i = 0;
	    // open directory and walk through the filenames
	    while ($file = readdir($handler)) {
			$extension = $this->get_file_extension($file);

		    // if file isn't this directory or its parent, add it to the results
		    if(!is_dir($directory_base_path . $file) && $extension == 'php') {
			    if ($file != "." && $file != "..") {
					$withoutExt = pathinfo($file, PATHINFO_FILENAME);
					$results[] = $withoutExt;
				}
		    }
		    $i++;
	    }
	
	    // tidy up: close the handler
	    closedir($handler);
	
	    // done!
	    return $results;
	}
        
	function get_smp_templates($template_dir,$type=false,$name) 
	{
		//ALT_TEMPLATE_DIR
		if($type == 'album') {
                    $album_dir = $template_dir .'albums/';
                    if(is_dir($album_dir)) {
                        $template_dir = $album_dir;
                    } else {
                        $template_dir = ALT_TEMPLATE_DIR .'albums/';
                    }
                    
		} elseif($type == 'widget') {
                    $widget_dir = $template_dir .'widgets/';
                    if(is_dir($widget_dir)) {
                        $template_dir = $widget_dir;
                    } else {
                        $template_dir = ALT_TEMPLATE_DIR .'widgets/';
                    }
                }
                
		$templates = $this->directory_list($template_dir,$type);
		
		$post_templates = array();
		
		if ( is_array( $templates ) ) {
			
			
			$j = 0;
			foreach ( $templates as $template ) {
				$basename = $template_dir . $template.'.php';//str_replace($base, '', $template['value'].'.php');
				
				$template_data[$j] = htmlentities(implode( '', file( $basename )));
				
				if ( preg_match( '|'.$name.':(.*)$|mi', $template_data[$j], $name_new ) )
                                    $name_new = _cleanup_header_comment( $name_new[1] );

				if ( !empty( $name_new ) && !is_array($name_new) ) {
					$post_templates[$j]['value'] = $template;
					$post_templates[$j]['name'] = $name_new;
				}
				$j++;
			}
		}
                
		return $post_templates;
	}
}
global $custom_post_type;
$custom_post_type = new Admin_CustomPostType();
